/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.*;

import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;

import org.gfxtest.framework.GfxTestConfiguration;

/**
 * This test renders various dashed arcs using identity transformation matrix.
 *
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.ARC)
@RenderStyle(RenderStyles.DASH)
@Transformation(Transformations.NONE)
@Zoom(1)
public class DashedArcs extends GfxTest
{

    @Override
    protected void drawEntity(TestImage image, Graphics2D graphics, int testNumber, EntityRenderingStyle entityRenderingStyle)
    {
        graphics.setStroke(new BasicStroke(entityRenderingStyle.getWidth(), entityRenderingStyle.getCap(), entityRenderingStyle.getJoin(), 1.0f, entityRenderingStyle.getDash(), 0.0f));
        int xc = image.getCenterX();
        int yc = image.getCenterY();
        int majorRadius = (xc > yc ? yc : xc) - 20;

        for (int radius = majorRadius; radius >= MINOR_RADIUS; radius -= RADIUS_STEP)
        {
            double r = ((double) radius - MINOR_RADIUS) / (majorRadius - MINOR_RADIUS);
            Color color = new Color(Color.HSBtoRGB((float)r, 1.0f, 1.0f));
            graphics.setColor(color);
            graphics.drawArc(xc - radius, yc - radius, radius << 1, radius << 1, (int) (r * 360.0), 180);
        }
        drawCross(graphics, xc, yc, CROSS_SIZE);
    }

	@Override
    protected void runOtherTests(GfxTestConfiguration configuration)
    {
        drawEntityWithVariousStyles(configuration, false, false, true, false, true, false);
    }

    public static void main(String[] args)
    {
        new DashedArcs().runTestSuite(args);
    }

}
